==> solid-bootstrap-0.1.1.tgz: package/AccordionButton.jsx <==
// ported from https://github.com/react-bootstrap/react-bootstrap/blob/f11723114d532cfce840417834a73733a8436414/src/AccordionButton.tsx
import classNames from "classnames";
import { mergeProps, splitProps, useContext } from "solid-js";
import { Dynamic } from "solid-js/web";
import { callEventHandler } from "solid-bootstrap-core/utils";
import AccordionContext from "./AccordionContext";
import AccordionItemContext from "./AccordionItemContext";
import { useBootstrapPrefix } from "./ThemeProvider";
export function useAccordionButton(eventKey, onClick) {
    const context = useContext(AccordionContext);
    return (e) => {
        /*
          Compare the event key in context with the given event key.
          If they are the same, then collapse the component.
        */
        const eventKeyPassed = eventKey === context.activeEventKey ? null : eventKey;
        if (context.onSelect)
            context.onSelect(eventKeyPassed, e);
        callEventHandler(onClick, e);
    };
}
const defaultProps = {
    as: "button",
};
const AccordionButton = (p) => {
    const [local, props] = splitProps(mergeProps(defaultProps, p), [
        "as",
        "bsPrefix",
        "className",
        "onClick",
    ]);
    const bsPrefix = useBootstrapPrefix(local.bsPrefix, "accordion-button");
    const itemContext = useContext(AccordionItemContext);
    const accordionOnClick = useAccordionButton(itemContext.eventKey, local.onClick);
    const accordianContext = useContext(AccordionContext);
    return (<Dynamic component={local.as} onClick={accordionOnClick} {...props} type={local.as === "button" ? "button" : undefined} aria-expanded={itemContext.eventKey === accordianContext.activeEventKey} className={classNames(local.className, bsPrefix, itemContext.eventKey !== accordianContext.activeEventKey && "collapsed")}/>);
};
export default AccordionButton;

==> solid-bootstrap-0.1.11.tgz: package/AccordionButton.jsx <==
// ported from https://github.com/react-bootstrap/react-bootstrap/blob/f11723114d532cfce840417834a73733a8436414/src/AccordionButton.tsx
import classNames from "classnames";
import { mergeProps, splitProps, useContext } from "solid-js";
import { Dynamic } from "solid-js/web";
import { callEventHandler } from "solid-bootstrap-core/utils";
import AccordionContext from "./AccordionContext";
import AccordionItemContext from "./AccordionItemContext";
import { useBootstrapPrefix } from "./ThemeProvider";
export function useAccordionButton(eventKey, onClick) {
    const context = useContext(AccordionContext);
    return (e) => {
        /*
          Compare the event key in context with the given event key.
          If they are the same, then collapse the component.
        */
        const eventKeyPassed = eventKey === context.activeEventKey ? null : eventKey;
        if (context.onSelect)
            context.onSelect(eventKeyPassed, e);
        callEventHandler(onClick, e);
    };
}
const defaultProps = {
    as: "button",
};
const AccordionButton = (p) => {
    const [local, props] = splitProps(mergeProps(defaultProps, p), [
        "as",
        "bsPrefix",
        "className",
        "onClick",
    ]);
    const bsPrefix = useBootstrapPrefix(local.bsPrefix, "accordion-button");
    const itemContext = useContext(AccordionItemContext);
    const accordionOnClick = useAccordionButton(itemContext.eventKey, local.onClick);
    const accordianContext = useContext(AccordionContext);
    return (<Dynamic component={local.as} onClick={accordionOnClick} {...props} type={local.as === "button" ? "button" : undefined} aria-expanded={itemContext.eventKey === accordianContext.activeEventKey} className={classNames(local.className, bsPrefix, itemContext.eventKey !== accordianContext.activeEventKey && "collapsed")}>
      {props.children}
    </Dynamic>);
};
export default AccordionButton;
